
options nodate;
title;
options  formchar="|----|+|---+=|-/\<>*";

PROC IMPORT OUT= WORK.autism 
            DATAFILE= "autism.csv" 
            DBMS=CSV REPLACE;
     GETNAMES=YES;
     DATAROW=2; 
RUN;

title "Autism Study: Descriptive Statistics";
proc freq data=autism;
  tables age;
  tables sicdegp * age / norow nocol nopercent;
run;

proc means data=autism min p25 median mean p75 max nmiss maxdec=2;
   var vsae;
run;
proc means data=autism;
  class age;
  var vsae;
run;
proc freq data=autism;
  tables sicdegp;
  where age=2;
run;

/*Figure 6.1: VSAE vs. Age for each Child, By SICDEGP*/

proc sort data=autism;
  by sicdegp childid age;
run;
goptions reset=all;
goptions device=win target=winprtm ftext=swissb fby=swissb hby=2 ;
axis1 order= 0 to 200 by 50;
axis2 order= 2 to 14 by 2 label=(height=1.5 "AGE (Years)");
symbol1 color=black value=circle line=1 interpol=join r=156;

title ;
proc gplot data=autism;
  by sicdegp;
  plot vsae*age = childid / nolegend vaxis = axis1 haxis=axis2;
run; quit;

/*Figure 6.2: Mean Profiles by SICDEGP*/

/*First, calculate mean of VSAE for each level of SICDEGP and AGE
   and store in a new data set called meandat*/
proc sort data=autism;
  by sicdegp age;
run;

proc means data=autism noprint;
  by sicdegp age;
  output out=meandat mean(vsae)=mean_vsae;
run;

/*Merge the mean with the original data, 
  so we can use it in the plot*/
data autism_meandat;
  merge autism meandat;
  by sicdegp age;
run;

axis1 order= 0 to 200 by 50 label=(angle=90 height=1.5 "VSAE");
symbol1 color=black value=none line=1 interpol=join r=1;
symbol2 color=black value=circle interpol=none r=612; 

title;
proc gplot data=autism_meandat;
  by sicdegp;
  plot mean_vsae*age vsae*age  /   overlay nolegend vaxis = axis1 haxis=axis2;
run; quit;




