PROC IMPORT OUT= WORK.autism 
            DATAFILE= "autism.csv" 
            DBMS=CSV REPLACE;
     GETNAMES=YES;
     DATAROW=2; 
RUN;

data autism2;
   set autism;
   age_2 = age-2;
   age_2sq = age_2*age_2;
run;


Title "Model 6.1";
proc mixed data=autism2 covtest;
   class childid sicdegp;
   model vsae = age_2 age_2sq sicdegp age_2*sicdegp 
	age_2sq*sicdegp / solution ddfm=sat;
   random int age_2 age_2sq / subject=childid type=un g v
                                 solution;
run;

Title "Model 6.1 (nobound option)";
proc mixed data=autism2 covtest nobound;
   class childid sicdegp;
   model vsae = age_2 age_2sq sicdegp age_2*sicdegp 
	age_2sq*sicdegp / solution ddfm=sat;
   random int age_2 age_2sq / subject=childid type=un g v
                                 solution;
run;

Title "Model 6.2";
proc mixed data=autism2 covtest;
   class childid sicdegp;
   model vsae = age_2 age_2sq sicdegp age_2*sicdegp 
	age_2sq*sicdegp / solution ddfm=sat;
   random age_2 age_2sq / subject=childid type=un g;
run;

/* for likelihood ratio tests of Hyp. 6.1 and 6.2 */

proc mixed data=autism2 covtest;
   class childid sicdegp;
   model vsae = age_2 age_2sq sicdegp age_2*sicdegp 
	age_2sq*sicdegp / solution ddfm=sat;
   random age_2 / subject=childid type=un g;
run;

title "Model 6.2 (ML)";
proc mixed data=autism2 covtest method = ML;
   class childid sicdegp;
   model vsae = age_2 age_2sq sicdegp age_2*sicdegp 
	age_2sq*sicdegp / solution ddfm=sat;
   random age_2 age_2sq / subject=childid type=un;
run;

title "Model 6.3 (ML)";
proc mixed data=autism2 covtest method = ML;
   class childid sicdegp;
   model vsae = age_2 age_2sq sicdegp age_2*sicdegp 
	           / solution ddfm=sat;
   random age_2 age_2sq / subject=childid type=un;
run;

title "Model 6.3 (REML)";
ods output influence=inf_dat solutionR=eblup_dat;
ods exclude influence solutionR;
proc mixed data = autism2 covtest;
   class childid sicdegp;
   model vsae = sicdegp age_2 age_2sq age_2*sicdegp / 
                solution ddfm=sat influence;
   random age_2 age_2sq /
			subject = childid solution g v vcorr type = un;
run;


title "Model 6.3 (REML) with Estimate Statements";
ods output influence=inf_dat solutionR=eblup_dat;
ods exclude influence solutionR;
proc mixed data = autism2 covtest;
   class childid sicdegp;
   model vsae = sicdegp age_2 age_2sq age_2*sicdegp / 
                solution ddfm=sat influence;
   random age_2 age_2sq /
			subject = childid solution g v vcorr type = un;

   estimate "Intercept for SICDEGP=1" int 1 sicdegp 1 0 0;
   estimate "Intercept for SICDEGP=2" int 1 sicdegp 0 1 0;
   estimate "Intercept for SICDEGP=3" int 1 sicdegp 0 0 1;

   estimate "Slope for SICDEGP=1" age_2 1 
                                   age_2*sicdegp 1 0 0;

   estimate "Slope for SICDEGP=2" age_2 1
                                   age_2*sicdegp 0 1 0;
   estimate "Slope for SICDEGP=3" age_2 1
                                   age_2*sicdegp 0 0 1;

   estimate "Diff in Slope Gp 1 vs 3" age_2*sicdegp 1 0 -1; 

run;

title "Marginal Model w/ Unstructured Covariance Matrix";
proc mixed data=autism2 noclprint covtest ;
   class childid sicdegp age;
   model vsae = sicdegp age_2 age_2sq age_2*sicdegp 
        / solution ddfm=bw;
   repeated age / subject=childid type=un r rcorr;
run;









