OPTIONS FORMCHAR="|----|+|---+=|-/\<>*" ;
options nodate pageno=1;

data ratbrain;
  infile "rat_brain.dat" firstobs=2 dlm="09"X;
  input animal $ treatment region activate;
  if treatment = 1 then treat = 0;
  if treatment = 2 then treat = 1;
run;
proc format;
  value regionfmt 1="BST" 2 = "LS" 3="VDB";
  value trtfmt 1="Basal" 2="Carbachol";
run;

/*Descriptive Statistics for Rat Brain Data*/
title "Descriptive Statistics";
proc means data=ratbrain;
  class treatment region;
  var activate;
  format treatment trtfmt. region regionfmt.;
run;
 
/*Figure 5.1: Plot of Activation by Treatment and Brain Region*/
proc sort data=ratbrain;
  by  treatment animal region;
run;

goptions reset=all;
goptions device=win target=winprtm ftext=swissb fby=swissb hby=2 ;

symbol1 color = black interpol=join line=1;
symbol2 color = black interpol=join line=2;
symbol3 color = black interpol=join line=3;
symbol4 color = black interpol=join line=4;
symbol5 color = black interpol=join line=5;

axis1 order=0 to 800 by 200 label = (font=swissb height=1.5 angle=90 "Activation" );
axis2 order=1 to 3 by 1 label=( font=swissb height=2 "Brain Region");
legend frame offset=(2,2) label= (height=1.5 "Animal:");

proc gplot data=ratbrain;
  by treatment;
  plot activate*region = animal / vaxis=axis1 haxis=axis2 legend=legend1;
  format treatment trtfmt. region regionfmt.;
run; quit;


