options pageno=1;
OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";

data ratbrain;
  infile "rat_brain.dat" firstobs=2 dlm="09"X;
  input animal $ treatment region activate;
  if treatment = 1 then treat = 0;
  if treatment = 2 then treat = 1;
run;
proc format;
  value regionfmt 1="BST" 2 = "LS" 3="VDB";
  value trtfmt 1="Basal" 2="Carbachol";
run;


title "Model 5.2";
proc mixed data = ratbrain covtest; 
  class animal region;
  model activate = region treat region*treat / residual solution outpred=resids;
  random int treat / subject = animal type = un solution v vcorr;
run;

/*Figure 5.3: Normal QQ Plot for Conditional Residuals*/
/*Note: X and Y axes are swapped in SAS compared to SPSS for QQ plots*/

goptions reset=all;
goptions device=win target=winprtm ftext=swissb fby=swissb hby=2;
symbol1 color = black value=circle;
title "Figure 5.3";
proc univariate data=resids noprint;
  var resid;
  qqplot / normal (mu=est sigma=est);
run;

/*Figure 5.4: Conditional Residuals vs. Conditional Predicted Values*/
symbol1 color = black value=circle;
symbol2 color = black value=triangle;
axis1 order = -40 to 40 by 20 offset=(4,4) label=(angle=90 height=1.5 "Conditional Residuals");
axis2 order = 0 to 800 by 200 offset=(4,4) label = (height=1.5 "Conditional Predicted Values");
legend frame ;
title "Figure 5.4";
proc gplot data=resids;
  plot resid * pred = treatment / vaxis=axis1 haxis=axis2 legend=legend1;
  format resid 6.2 pred 4. treatment trtfmt.;
run; quit;
